# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: governance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .github.com.mwitkow.go_proto_validators import validator_pb2 as github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2
from . import markets_pb2 as markets__pb2
from . import vega_pb2 as vega__pb2
from . import assets_pb2 as assets__pb2
from .oracles.v1 import oracle_spec_pb2 as oracles_dot_v1_dot_oracle__spec__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='governance.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'\n\024io.vegaprotocol.vegaZ\037code.vegaprotocol.io/vega/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10governance.proto\x12\x04vega\x1a\x36github.com/mwitkow/go-proto-validators/validator.proto\x1a\rmarkets.proto\x1a\nvega.proto\x1a\x0c\x61ssets.proto\x1a\x1coracles/v1/oracle_spec.proto\"\xa4\x02\n\rFutureProduct\x12\"\n\x08maturity\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x08maturity\x12\x31\n\x10settlement_asset\x18\x02 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x0fsettlementAsset\x12%\n\nquote_name\x18\x03 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\tquoteName\x12\x44\n\x0boracle_spec\x18\x05 \x01(\x0b\x32#.oracles.v1.OracleSpecConfigurationR\noracleSpec\x12O\n\x13oracle_spec_binding\x18\x06 \x01(\x0b\x32\x1f.vega.OracleSpecToFutureBindingR\x11oracleSpecBinding\"\x8b\x01\n\x17InstrumentConfiguration\x12\x1a\n\x04name\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x04name\x12\x1a\n\x04\x63ode\x18\x02 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x04\x63ode\x12-\n\x06\x66uture\x18\x64 \x01(\x0b\x32\x13.vega.FutureProductH\x00R\x06\x66utureB\t\n\x07product\"\xfc\x04\n\x16NewMarketConfiguration\x12\x45\n\ninstrument\x18\x01 \x01(\x0b\x32\x1d.vega.InstrumentConfigurationB\x06\xe2\xdf\x1f\x02 \x01R\ninstrument\x12.\n\x0e\x64\x65\x63imal_places\x18\x02 \x01(\x04\x42\x07\xe2\xdf\x1f\x03\x18\x96\x01R\rdecimalPlaces\x12\x1a\n\x08metadata\x18\x03 \x03(\tR\x08metadata\x12_\n\x1bprice_monitoring_parameters\x18\x04 \x01(\x0b\x32\x1f.vega.PriceMonitoringParametersR\x19priceMonitoringParameters\x12k\n\x1fliquidity_monitoring_parameters\x18\x05 \x01(\x0b\x32#.vega.LiquidityMonitoringParametersR\x1dliquidityMonitoringParameters\x12\x31\n\x06simple\x18\x64 \x01(\x0b\x32\x17.vega.SimpleModelParamsH\x00R\x06simple\x12\x39\n\nlog_normal\x18\x65 \x01(\x0b\x32\x18.vega.LogNormalRiskModelH\x00R\tlogNormal\x12:\n\ncontinuous\x18\xc8\x01 \x01(\x0b\x32\x17.vega.ContinuousTradingH\x01R\ncontinuous\x12\x34\n\x08\x64iscrete\x18\xc9\x01 \x01(\x0b\x32\x15.vega.DiscreteTradingH\x01R\x08\x64iscreteB\x11\n\x0frisk_parametersB\x0e\n\x0ctrading_mode\"\xc8\x01\n\x13NewMarketCommitment\x12+\n\x11\x63ommitment_amount\x18\x01 \x01(\x04R\x10\x63ommitmentAmount\x12\x10\n\x03\x66\x65\x65\x18\x02 \x01(\tR\x03\x66\x65\x65\x12*\n\x05sells\x18\x03 \x03(\x0b\x32\x14.vega.LiquidityOrderR\x05sells\x12(\n\x04\x62uys\x18\x04 \x03(\x0b\x32\x14.vega.LiquidityOrderR\x04\x62uys\x12\x1c\n\treference\x18\x05 \x01(\tR\treference\"\x99\x01\n\tNewMarket\x12>\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x1c.vega.NewMarketConfigurationB\x06\xe2\xdf\x1f\x02 \x01R\x07\x63hanges\x12L\n\x14liquidity_commitment\x18\x02 \x01(\x0b\x32\x19.vega.NewMarketCommitmentR\x13liquidityCommitment\"\x0e\n\x0cUpdateMarket\"R\n\x16UpdateNetworkParameter\x12\x38\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x16.vega.NetworkParameterB\x06\xe2\xdf\x1f\x02 \x01R\x07\x63hanges\"?\n\x08NewAsset\x12\x33\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x11.vega.AssetSourceB\x06\xe2\xdf\x1f\x02 \x01R\x07\x63hanges\"\xb0\x03\n\rProposalTerms\x12\x33\n\x11\x63losing_timestamp\x18\x01 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00R\x10\x63losingTimestamp\x12\x37\n\x13\x65nactment_timestamp\x18\x02 \x01(\x03\x42\x06\xe2\xdf\x1f\x02\x10\x00R\x12\x65nactmentTimestamp\x12\x31\n\x14validation_timestamp\x18\x03 \x01(\x03R\x13validationTimestamp\x12\x39\n\rupdate_market\x18\x65 \x01(\x0b\x32\x12.vega.UpdateMarketH\x00R\x0cupdateMarket\x12\x30\n\nnew_market\x18\x66 \x01(\x0b\x32\x0f.vega.NewMarketH\x00R\tnewMarket\x12X\n\x18update_network_parameter\x18g \x01(\x0b\x32\x1c.vega.UpdateNetworkParameterH\x00R\x16updateNetworkParameter\x12-\n\tnew_asset\x18h \x01(\x0b\x32\x0e.vega.NewAssetH\x00R\x08newAssetB\x08\n\x06\x63hange\"\x86\x03\n\x0eGovernanceData\x12*\n\x08proposal\x18\x01 \x01(\x0b\x32\x0e.vega.ProposalR\x08proposal\x12\x1c\n\x03yes\x18\x02 \x03(\x0b\x32\n.vega.VoteR\x03yes\x12\x1a\n\x02no\x18\x03 \x03(\x0b\x32\n.vega.VoteR\x02no\x12?\n\tyes_party\x18\x04 \x03(\x0b\x32\".vega.GovernanceData.YesPartyEntryR\x08yesParty\x12<\n\x08no_party\x18\x05 \x03(\x0b\x32!.vega.GovernanceData.NoPartyEntryR\x07noParty\x1aG\n\rYesPartyEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12 \n\x05value\x18\x02 \x01(\x0b\x32\n.vega.VoteR\x05value:\x02\x38\x01\x1a\x46\n\x0cNoPartyEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12 \n\x05value\x18\x02 \x01(\x0b\x32\n.vega.VoteR\x05value:\x02\x38\x01\"\xbf\x03\n\x08Proposal\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1c\n\treference\x18\x02 \x01(\tR\treference\x12!\n\x08party_id\x18\x03 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x07partyId\x12\x33\n\x05state\x18\x04 \x01(\x0e\x32\x14.vega.Proposal.StateB\x07\xe2\xdf\x1f\x03\x88\x01\x01R\x05state\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x31\n\x05terms\x18\x06 \x01(\x0b\x32\x13.vega.ProposalTermsB\x06\xe2\xdf\x1f\x02 \x01R\x05terms\x12+\n\x06reason\x18\x07 \x01(\x0e\x32\x13.vega.ProposalErrorR\x06reason\"\xae\x01\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cSTATE_FAILED\x10\x01\x12\x0e\n\nSTATE_OPEN\x10\x02\x12\x10\n\x0cSTATE_PASSED\x10\x03\x12\x12\n\x0eSTATE_REJECTED\x10\x04\x12\x12\n\x0eSTATE_DECLINED\x10\x05\x12\x11\n\rSTATE_ENACTED\x10\x06\x12\x1f\n\x1bSTATE_WAITING_FOR_NODE_VOTE\x10\x07\"\xde\x01\n\x04Vote\x12!\n\x08party_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x07partyId\x12/\n\x05value\x18\x02 \x01(\x0e\x32\x10.vega.Vote.ValueB\x07\xe2\xdf\x1f\x03\x88\x01\x01R\x05value\x12\'\n\x0bproposal_id\x18\x03 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\nproposalId\x12\x1c\n\ttimestamp\x18\x04 \x01(\x03R\ttimestamp\";\n\x05Value\x12\x15\n\x11VALUE_UNSPECIFIED\x10\x00\x12\x0c\n\x08VALUE_NO\x10\x01\x12\r\n\tVALUE_YES\x10\x02*\xc6\t\n\rProposalError\x12\x1e\n\x1aPROPOSAL_ERROR_UNSPECIFIED\x10\x00\x12&\n\"PROPOSAL_ERROR_CLOSE_TIME_TOO_SOON\x10\x01\x12&\n\"PROPOSAL_ERROR_CLOSE_TIME_TOO_LATE\x10\x02\x12&\n\"PROPOSAL_ERROR_ENACT_TIME_TOO_SOON\x10\x03\x12&\n\"PROPOSAL_ERROR_ENACT_TIME_TOO_LATE\x10\x04\x12&\n\"PROPOSAL_ERROR_INSUFFICIENT_TOKENS\x10\x05\x12.\n*PROPOSAL_ERROR_INVALID_INSTRUMENT_SECURITY\x10\x06\x12\x1d\n\x19PROPOSAL_ERROR_NO_PRODUCT\x10\x07\x12&\n\"PROPOSAL_ERROR_UNSUPPORTED_PRODUCT\x10\x08\x12\x33\n/PROPOSAL_ERROR_INVALID_FUTURE_PRODUCT_TIMESTAMP\x10\t\x12-\n)PROPOSAL_ERROR_PRODUCT_MATURITY_IS_PASSED\x10\n\x12\"\n\x1ePROPOSAL_ERROR_NO_TRADING_MODE\x10\x0b\x12+\n\'PROPOSAL_ERROR_UNSUPPORTED_TRADING_MODE\x10\x0c\x12)\n%PROPOSAL_ERROR_NODE_VALIDATION_FAILED\x10\r\x12.\n*PROPOSAL_ERROR_MISSING_BUILTIN_ASSET_FIELD\x10\x0e\x12\x31\n-PROPOSAL_ERROR_MISSING_ERC20_CONTRACT_ADDRESS\x10\x0f\x12 \n\x1cPROPOSAL_ERROR_INVALID_ASSET\x10\x10\x12*\n&PROPOSAL_ERROR_INCOMPATIBLE_TIMESTAMPS\x10\x11\x12%\n!PROPOSAL_ERROR_NO_RISK_PARAMETERS\x10\x12\x12\x30\n,PROPOSAL_ERROR_NETWORK_PARAMETER_INVALID_KEY\x10\x13\x12\x32\n.PROPOSAL_ERROR_NETWORK_PARAMETER_INVALID_VALUE\x10\x14\x12\x36\n2PROPOSAL_ERROR_NETWORK_PARAMETER_VALIDATION_FAILED\x10\x15\x12\x35\n1PROPOSAL_ERROR_OPENING_AUCTION_DURATION_TOO_SMALL\x10\x16\x12\x35\n1PROPOSAL_ERROR_OPENING_AUCTION_DURATION_TOO_LARGE\x10\x17\x12\x36\n2PROPOSAL_ERROR_MARKET_MISSING_LIQUIDITY_COMMITMENT\x10\x18\x12/\n+PROPOSAL_ERROR_COULD_NOT_INSTANTIATE_MARKET\x10\x19\x12)\n%PROPOSAL_ERROR_INVALID_FUTURE_PRODUCT\x10\x1a\x42\x37\n\x14io.vegaprotocol.vegaZ\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2.DESCRIPTOR,markets__pb2.DESCRIPTOR,vega__pb2.DESCRIPTOR,assets__pb2.DESCRIPTOR,oracles_dot_v1_dot_oracle__spec__pb2.DESCRIPTOR,])

_PROPOSALERROR = _descriptor.EnumDescriptor(
  name='ProposalError',
  full_name='vega.ProposalError',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_CLOSE_TIME_TOO_SOON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_CLOSE_TIME_TOO_LATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_ENACT_TIME_TOO_SOON', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_ENACT_TIME_TOO_LATE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_INSUFFICIENT_TOKENS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_INVALID_INSTRUMENT_SECURITY', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_NO_PRODUCT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_UNSUPPORTED_PRODUCT', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_INVALID_FUTURE_PRODUCT_TIMESTAMP', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_PRODUCT_MATURITY_IS_PASSED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_NO_TRADING_MODE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_UNSUPPORTED_TRADING_MODE', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_NODE_VALIDATION_FAILED', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_MISSING_BUILTIN_ASSET_FIELD', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_MISSING_ERC20_CONTRACT_ADDRESS', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_INVALID_ASSET', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_INCOMPATIBLE_TIMESTAMPS', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_NO_RISK_PARAMETERS', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_NETWORK_PARAMETER_INVALID_KEY', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_NETWORK_PARAMETER_INVALID_VALUE', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_NETWORK_PARAMETER_VALIDATION_FAILED', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_OPENING_AUCTION_DURATION_TOO_SMALL', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_OPENING_AUCTION_DURATION_TOO_LARGE', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_MARKET_MISSING_LIQUIDITY_COMMITMENT', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_COULD_NOT_INSTANTIATE_MARKET', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOSAL_ERROR_INVALID_FUTURE_PRODUCT', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3257,
  serialized_end=4479,
)
_sym_db.RegisterEnumDescriptor(_PROPOSALERROR)

ProposalError = enum_type_wrapper.EnumTypeWrapper(_PROPOSALERROR)
PROPOSAL_ERROR_UNSPECIFIED = 0
PROPOSAL_ERROR_CLOSE_TIME_TOO_SOON = 1
PROPOSAL_ERROR_CLOSE_TIME_TOO_LATE = 2
PROPOSAL_ERROR_ENACT_TIME_TOO_SOON = 3
PROPOSAL_ERROR_ENACT_TIME_TOO_LATE = 4
PROPOSAL_ERROR_INSUFFICIENT_TOKENS = 5
PROPOSAL_ERROR_INVALID_INSTRUMENT_SECURITY = 6
PROPOSAL_ERROR_NO_PRODUCT = 7
PROPOSAL_ERROR_UNSUPPORTED_PRODUCT = 8
PROPOSAL_ERROR_INVALID_FUTURE_PRODUCT_TIMESTAMP = 9
PROPOSAL_ERROR_PRODUCT_MATURITY_IS_PASSED = 10
PROPOSAL_ERROR_NO_TRADING_MODE = 11
PROPOSAL_ERROR_UNSUPPORTED_TRADING_MODE = 12
PROPOSAL_ERROR_NODE_VALIDATION_FAILED = 13
PROPOSAL_ERROR_MISSING_BUILTIN_ASSET_FIELD = 14
PROPOSAL_ERROR_MISSING_ERC20_CONTRACT_ADDRESS = 15
PROPOSAL_ERROR_INVALID_ASSET = 16
PROPOSAL_ERROR_INCOMPATIBLE_TIMESTAMPS = 17
PROPOSAL_ERROR_NO_RISK_PARAMETERS = 18
PROPOSAL_ERROR_NETWORK_PARAMETER_INVALID_KEY = 19
PROPOSAL_ERROR_NETWORK_PARAMETER_INVALID_VALUE = 20
PROPOSAL_ERROR_NETWORK_PARAMETER_VALIDATION_FAILED = 21
PROPOSAL_ERROR_OPENING_AUCTION_DURATION_TOO_SMALL = 22
PROPOSAL_ERROR_OPENING_AUCTION_DURATION_TOO_LARGE = 23
PROPOSAL_ERROR_MARKET_MISSING_LIQUIDITY_COMMITMENT = 24
PROPOSAL_ERROR_COULD_NOT_INSTANTIATE_MARKET = 25
PROPOSAL_ERROR_INVALID_FUTURE_PRODUCT = 26


_PROPOSAL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='vega.Proposal.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_FAILED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_OPEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_PASSED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_REJECTED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_DECLINED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_ENACTED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_WAITING_FOR_NODE_VOTE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2855,
  serialized_end=3029,
)
_sym_db.RegisterEnumDescriptor(_PROPOSAL_STATE)

_VOTE_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='vega.Vote.Value',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VALUE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALUE_NO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALUE_YES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3195,
  serialized_end=3254,
)
_sym_db.RegisterEnumDescriptor(_VOTE_VALUE)


_FUTUREPRODUCT = _descriptor.Descriptor(
  name='FutureProduct',
  full_name='vega.FutureProduct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maturity', full_name='vega.FutureProduct.maturity', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='maturity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_asset', full_name='vega.FutureProduct.settlement_asset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='settlementAsset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_name', full_name='vega.FutureProduct.quote_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='quoteName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_spec', full_name='vega.FutureProduct.oracle_spec', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_spec_binding', full_name='vega.FutureProduct.oracle_spec_binding', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleSpecBinding', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=446,
)


_INSTRUMENTCONFIGURATION = _descriptor.Descriptor(
  name='InstrumentConfiguration',
  full_name='vega.InstrumentConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='vega.InstrumentConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='vega.InstrumentConfiguration.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future', full_name='vega.InstrumentConfiguration.future', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='future', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='product', full_name='vega.InstrumentConfiguration.product',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=449,
  serialized_end=588,
)


_NEWMARKETCONFIGURATION = _descriptor.Descriptor(
  name='NewMarketConfiguration',
  full_name='vega.NewMarketConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instrument', full_name='vega.NewMarketConfiguration.instrument', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', json_name='instrument', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimal_places', full_name='vega.NewMarketConfiguration.decimal_places', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\003\030\226\001', json_name='decimalPlaces', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='vega.NewMarketConfiguration.metadata', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_monitoring_parameters', full_name='vega.NewMarketConfiguration.price_monitoring_parameters', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='priceMonitoringParameters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidity_monitoring_parameters', full_name='vega.NewMarketConfiguration.liquidity_monitoring_parameters', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='liquidityMonitoringParameters', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple', full_name='vega.NewMarketConfiguration.simple', index=5,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='simple', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_normal', full_name='vega.NewMarketConfiguration.log_normal', index=6,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logNormal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continuous', full_name='vega.NewMarketConfiguration.continuous', index=7,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continuous', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discrete', full_name='vega.NewMarketConfiguration.discrete', index=8,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='discrete', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='risk_parameters', full_name='vega.NewMarketConfiguration.risk_parameters',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='trading_mode', full_name='vega.NewMarketConfiguration.trading_mode',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=591,
  serialized_end=1227,
)


_NEWMARKETCOMMITMENT = _descriptor.Descriptor(
  name='NewMarketCommitment',
  full_name='vega.NewMarketCommitment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commitment_amount', full_name='vega.NewMarketCommitment.commitment_amount', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitmentAmount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='vega.NewMarketCommitment.fee', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fee', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sells', full_name='vega.NewMarketCommitment.sells', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sells', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buys', full_name='vega.NewMarketCommitment.buys', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='buys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.NewMarketCommitment.reference', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1230,
  serialized_end=1430,
)


_NEWMARKET = _descriptor.Descriptor(
  name='NewMarket',
  full_name='vega.NewMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.NewMarket.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', json_name='changes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidity_commitment', full_name='vega.NewMarket.liquidity_commitment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='liquidityCommitment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1433,
  serialized_end=1586,
)


_UPDATEMARKET = _descriptor.Descriptor(
  name='UpdateMarket',
  full_name='vega.UpdateMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1588,
  serialized_end=1602,
)


_UPDATENETWORKPARAMETER = _descriptor.Descriptor(
  name='UpdateNetworkParameter',
  full_name='vega.UpdateNetworkParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.UpdateNetworkParameter.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', json_name='changes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1604,
  serialized_end=1686,
)


_NEWASSET = _descriptor.Descriptor(
  name='NewAsset',
  full_name='vega.NewAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.NewAsset.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', json_name='changes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1688,
  serialized_end=1751,
)


_PROPOSALTERMS = _descriptor.Descriptor(
  name='ProposalTerms',
  full_name='vega.ProposalTerms',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='closing_timestamp', full_name='vega.ProposalTerms.closing_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', json_name='closingTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enactment_timestamp', full_name='vega.ProposalTerms.enactment_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', json_name='enactmentTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_timestamp', full_name='vega.ProposalTerms.validation_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validationTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_market', full_name='vega.ProposalTerms.update_market', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updateMarket', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_market', full_name='vega.ProposalTerms.new_market', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newMarket', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_network_parameter', full_name='vega.ProposalTerms.update_network_parameter', index=5,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updateNetworkParameter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_asset', full_name='vega.ProposalTerms.new_asset', index=6,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newAsset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='change', full_name='vega.ProposalTerms.change',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1754,
  serialized_end=2186,
)


_GOVERNANCEDATA_YESPARTYENTRY = _descriptor.Descriptor(
  name='YesPartyEntry',
  full_name='vega.GovernanceData.YesPartyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='vega.GovernanceData.YesPartyEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.GovernanceData.YesPartyEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2436,
  serialized_end=2507,
)

_GOVERNANCEDATA_NOPARTYENTRY = _descriptor.Descriptor(
  name='NoPartyEntry',
  full_name='vega.GovernanceData.NoPartyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='vega.GovernanceData.NoPartyEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.GovernanceData.NoPartyEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2509,
  serialized_end=2579,
)

_GOVERNANCEDATA = _descriptor.Descriptor(
  name='GovernanceData',
  full_name='vega.GovernanceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='vega.GovernanceData.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='proposal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yes', full_name='vega.GovernanceData.yes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='yes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no', full_name='vega.GovernanceData.no', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='no', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yes_party', full_name='vega.GovernanceData.yes_party', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='yesParty', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_party', full_name='vega.GovernanceData.no_party', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='noParty', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GOVERNANCEDATA_YESPARTYENTRY, _GOVERNANCEDATA_NOPARTYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2189,
  serialized_end=2579,
)


_PROPOSAL = _descriptor.Descriptor(
  name='Proposal',
  full_name='vega.Proposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.Proposal.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.Proposal.reference', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.Proposal.party_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='vega.Proposal.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\003\210\001\001', json_name='state', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='vega.Proposal.timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terms', full_name='vega.Proposal.terms', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', json_name='terms', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='vega.Proposal.reason', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reason', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROPOSAL_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2582,
  serialized_end=3029,
)


_VOTE = _descriptor.Descriptor(
  name='Vote',
  full_name='vega.Vote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.Vote.party_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.Vote.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\003\210\001\001', json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal_id', full_name='vega.Vote.proposal_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='proposalId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='vega.Vote.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VOTE_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3032,
  serialized_end=3254,
)

_FUTUREPRODUCT.fields_by_name['oracle_spec'].message_type = oracles_dot_v1_dot_oracle__spec__pb2._ORACLESPECCONFIGURATION
_FUTUREPRODUCT.fields_by_name['oracle_spec_binding'].message_type = markets__pb2._ORACLESPECTOFUTUREBINDING
_INSTRUMENTCONFIGURATION.fields_by_name['future'].message_type = _FUTUREPRODUCT
_INSTRUMENTCONFIGURATION.oneofs_by_name['product'].fields.append(
  _INSTRUMENTCONFIGURATION.fields_by_name['future'])
_INSTRUMENTCONFIGURATION.fields_by_name['future'].containing_oneof = _INSTRUMENTCONFIGURATION.oneofs_by_name['product']
_NEWMARKETCONFIGURATION.fields_by_name['instrument'].message_type = _INSTRUMENTCONFIGURATION
_NEWMARKETCONFIGURATION.fields_by_name['price_monitoring_parameters'].message_type = markets__pb2._PRICEMONITORINGPARAMETERS
_NEWMARKETCONFIGURATION.fields_by_name['liquidity_monitoring_parameters'].message_type = markets__pb2._LIQUIDITYMONITORINGPARAMETERS
_NEWMARKETCONFIGURATION.fields_by_name['simple'].message_type = markets__pb2._SIMPLEMODELPARAMS
_NEWMARKETCONFIGURATION.fields_by_name['log_normal'].message_type = markets__pb2._LOGNORMALRISKMODEL
_NEWMARKETCONFIGURATION.fields_by_name['continuous'].message_type = markets__pb2._CONTINUOUSTRADING
_NEWMARKETCONFIGURATION.fields_by_name['discrete'].message_type = markets__pb2._DISCRETETRADING
_NEWMARKETCONFIGURATION.oneofs_by_name['risk_parameters'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['simple'])
_NEWMARKETCONFIGURATION.fields_by_name['simple'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['risk_parameters']
_NEWMARKETCONFIGURATION.oneofs_by_name['risk_parameters'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['log_normal'])
_NEWMARKETCONFIGURATION.fields_by_name['log_normal'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['risk_parameters']
_NEWMARKETCONFIGURATION.oneofs_by_name['trading_mode'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['continuous'])
_NEWMARKETCONFIGURATION.fields_by_name['continuous'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['trading_mode']
_NEWMARKETCONFIGURATION.oneofs_by_name['trading_mode'].fields.append(
  _NEWMARKETCONFIGURATION.fields_by_name['discrete'])
_NEWMARKETCONFIGURATION.fields_by_name['discrete'].containing_oneof = _NEWMARKETCONFIGURATION.oneofs_by_name['trading_mode']
_NEWMARKETCOMMITMENT.fields_by_name['sells'].message_type = vega__pb2._LIQUIDITYORDER
_NEWMARKETCOMMITMENT.fields_by_name['buys'].message_type = vega__pb2._LIQUIDITYORDER
_NEWMARKET.fields_by_name['changes'].message_type = _NEWMARKETCONFIGURATION
_NEWMARKET.fields_by_name['liquidity_commitment'].message_type = _NEWMARKETCOMMITMENT
_UPDATENETWORKPARAMETER.fields_by_name['changes'].message_type = vega__pb2._NETWORKPARAMETER
_NEWASSET.fields_by_name['changes'].message_type = assets__pb2._ASSETSOURCE
_PROPOSALTERMS.fields_by_name['update_market'].message_type = _UPDATEMARKET
_PROPOSALTERMS.fields_by_name['new_market'].message_type = _NEWMARKET
_PROPOSALTERMS.fields_by_name['update_network_parameter'].message_type = _UPDATENETWORKPARAMETER
_PROPOSALTERMS.fields_by_name['new_asset'].message_type = _NEWASSET
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['update_market'])
_PROPOSALTERMS.fields_by_name['update_market'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['new_market'])
_PROPOSALTERMS.fields_by_name['new_market'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['update_network_parameter'])
_PROPOSALTERMS.fields_by_name['update_network_parameter'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['new_asset'])
_PROPOSALTERMS.fields_by_name['new_asset'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_GOVERNANCEDATA_YESPARTYENTRY.fields_by_name['value'].message_type = _VOTE
_GOVERNANCEDATA_YESPARTYENTRY.containing_type = _GOVERNANCEDATA
_GOVERNANCEDATA_NOPARTYENTRY.fields_by_name['value'].message_type = _VOTE
_GOVERNANCEDATA_NOPARTYENTRY.containing_type = _GOVERNANCEDATA
_GOVERNANCEDATA.fields_by_name['proposal'].message_type = _PROPOSAL
_GOVERNANCEDATA.fields_by_name['yes'].message_type = _VOTE
_GOVERNANCEDATA.fields_by_name['no'].message_type = _VOTE
_GOVERNANCEDATA.fields_by_name['yes_party'].message_type = _GOVERNANCEDATA_YESPARTYENTRY
_GOVERNANCEDATA.fields_by_name['no_party'].message_type = _GOVERNANCEDATA_NOPARTYENTRY
_PROPOSAL.fields_by_name['state'].enum_type = _PROPOSAL_STATE
_PROPOSAL.fields_by_name['terms'].message_type = _PROPOSALTERMS
_PROPOSAL.fields_by_name['reason'].enum_type = _PROPOSALERROR
_PROPOSAL_STATE.containing_type = _PROPOSAL
_VOTE.fields_by_name['value'].enum_type = _VOTE_VALUE
_VOTE_VALUE.containing_type = _VOTE
DESCRIPTOR.message_types_by_name['FutureProduct'] = _FUTUREPRODUCT
DESCRIPTOR.message_types_by_name['InstrumentConfiguration'] = _INSTRUMENTCONFIGURATION
DESCRIPTOR.message_types_by_name['NewMarketConfiguration'] = _NEWMARKETCONFIGURATION
DESCRIPTOR.message_types_by_name['NewMarketCommitment'] = _NEWMARKETCOMMITMENT
DESCRIPTOR.message_types_by_name['NewMarket'] = _NEWMARKET
DESCRIPTOR.message_types_by_name['UpdateMarket'] = _UPDATEMARKET
DESCRIPTOR.message_types_by_name['UpdateNetworkParameter'] = _UPDATENETWORKPARAMETER
DESCRIPTOR.message_types_by_name['NewAsset'] = _NEWASSET
DESCRIPTOR.message_types_by_name['ProposalTerms'] = _PROPOSALTERMS
DESCRIPTOR.message_types_by_name['GovernanceData'] = _GOVERNANCEDATA
DESCRIPTOR.message_types_by_name['Proposal'] = _PROPOSAL
DESCRIPTOR.message_types_by_name['Vote'] = _VOTE
DESCRIPTOR.enum_types_by_name['ProposalError'] = _PROPOSALERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FutureProduct = _reflection.GeneratedProtocolMessageType('FutureProduct', (_message.Message,), {
  'DESCRIPTOR' : _FUTUREPRODUCT,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.FutureProduct)
  })
_sym_db.RegisterMessage(FutureProduct)

InstrumentConfiguration = _reflection.GeneratedProtocolMessageType('InstrumentConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _INSTRUMENTCONFIGURATION,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.InstrumentConfiguration)
  })
_sym_db.RegisterMessage(InstrumentConfiguration)

NewMarketConfiguration = _reflection.GeneratedProtocolMessageType('NewMarketConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _NEWMARKETCONFIGURATION,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewMarketConfiguration)
  })
_sym_db.RegisterMessage(NewMarketConfiguration)

NewMarketCommitment = _reflection.GeneratedProtocolMessageType('NewMarketCommitment', (_message.Message,), {
  'DESCRIPTOR' : _NEWMARKETCOMMITMENT,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewMarketCommitment)
  })
_sym_db.RegisterMessage(NewMarketCommitment)

NewMarket = _reflection.GeneratedProtocolMessageType('NewMarket', (_message.Message,), {
  'DESCRIPTOR' : _NEWMARKET,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewMarket)
  })
_sym_db.RegisterMessage(NewMarket)

UpdateMarket = _reflection.GeneratedProtocolMessageType('UpdateMarket', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMARKET,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.UpdateMarket)
  })
_sym_db.RegisterMessage(UpdateMarket)

UpdateNetworkParameter = _reflection.GeneratedProtocolMessageType('UpdateNetworkParameter', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENETWORKPARAMETER,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.UpdateNetworkParameter)
  })
_sym_db.RegisterMessage(UpdateNetworkParameter)

NewAsset = _reflection.GeneratedProtocolMessageType('NewAsset', (_message.Message,), {
  'DESCRIPTOR' : _NEWASSET,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewAsset)
  })
_sym_db.RegisterMessage(NewAsset)

ProposalTerms = _reflection.GeneratedProtocolMessageType('ProposalTerms', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALTERMS,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.ProposalTerms)
  })
_sym_db.RegisterMessage(ProposalTerms)

GovernanceData = _reflection.GeneratedProtocolMessageType('GovernanceData', (_message.Message,), {

  'YesPartyEntry' : _reflection.GeneratedProtocolMessageType('YesPartyEntry', (_message.Message,), {
    'DESCRIPTOR' : _GOVERNANCEDATA_YESPARTYENTRY,
    '__module__' : 'governance_pb2'
    # @@protoc_insertion_point(class_scope:vega.GovernanceData.YesPartyEntry)
    })
  ,

  'NoPartyEntry' : _reflection.GeneratedProtocolMessageType('NoPartyEntry', (_message.Message,), {
    'DESCRIPTOR' : _GOVERNANCEDATA_NOPARTYENTRY,
    '__module__' : 'governance_pb2'
    # @@protoc_insertion_point(class_scope:vega.GovernanceData.NoPartyEntry)
    })
  ,
  'DESCRIPTOR' : _GOVERNANCEDATA,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.GovernanceData)
  })
_sym_db.RegisterMessage(GovernanceData)
_sym_db.RegisterMessage(GovernanceData.YesPartyEntry)
_sym_db.RegisterMessage(GovernanceData.NoPartyEntry)

Proposal = _reflection.GeneratedProtocolMessageType('Proposal', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSAL,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.Proposal)
  })
_sym_db.RegisterMessage(Proposal)

Vote = _reflection.GeneratedProtocolMessageType('Vote', (_message.Message,), {
  'DESCRIPTOR' : _VOTE,
  '__module__' : 'governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.Vote)
  })
_sym_db.RegisterMessage(Vote)


DESCRIPTOR._options = None
_FUTUREPRODUCT.fields_by_name['maturity']._options = None
_FUTUREPRODUCT.fields_by_name['settlement_asset']._options = None
_FUTUREPRODUCT.fields_by_name['quote_name']._options = None
_INSTRUMENTCONFIGURATION.fields_by_name['name']._options = None
_INSTRUMENTCONFIGURATION.fields_by_name['code']._options = None
_NEWMARKETCONFIGURATION.fields_by_name['instrument']._options = None
_NEWMARKETCONFIGURATION.fields_by_name['decimal_places']._options = None
_NEWMARKET.fields_by_name['changes']._options = None
_UPDATENETWORKPARAMETER.fields_by_name['changes']._options = None
_NEWASSET.fields_by_name['changes']._options = None
_PROPOSALTERMS.fields_by_name['closing_timestamp']._options = None
_PROPOSALTERMS.fields_by_name['enactment_timestamp']._options = None
_GOVERNANCEDATA_YESPARTYENTRY._options = None
_GOVERNANCEDATA_NOPARTYENTRY._options = None
_PROPOSAL.fields_by_name['party_id']._options = None
_PROPOSAL.fields_by_name['state']._options = None
_PROPOSAL.fields_by_name['terms']._options = None
_VOTE.fields_by_name['party_id']._options = None
_VOTE.fields_by_name['value']._options = None
_VOTE.fields_by_name['proposal_id']._options = None
# @@protoc_insertion_point(module_scope)



import grpc
import itertools
import json
import re
from typing import Any, Dict, List

import google.rpc.status_pb2 as goog_status


def remove_control_chars(s: str) -> str:
    # https://stackoverflow.com/questions/92438
    control_chars = "".join(
        map(chr, itertools.chain(range(0x00, 0x20), range(0x7F, 0xA0)))
    )
    control_char_re = re.compile(f"[{re.escape(control_chars)}]")
    return control_char_re.sub("?", s)


def grpc_error_detail(err: grpc.RpcError) -> Dict[str, Any]:
    """
    This function takes a `grpc.RpcError` and returns a dict containing the
    error details.

    Usage example:

    ```python
    import vegaapiclient as vac
    grpc_client = vac.VegaTradingClient(node_grpc_url)
    grpc_request = ...
    try:
        grpc_response = grpc_client.NameOfEndpoint(grpc_request)
    except grpc.RpcError as exc:
        print(json.dumps(vac.grpc_error_detail(exc), indent=2, sort_keys=True))
        exit(1)
    ```
    """

    if not isinstance(err, grpc.RpcError):
        raise ValueError(f"Not a gRPC error: {err}")

    e: Dict[str, Any] = {}
    for arg in err.args:
        for attr in ["code", "details"]:
            if hasattr(arg, attr):
                e[attr] = str(getattr(arg, attr))

        if hasattr(arg, "debug_error_string"):
            try:
                parsed = json.loads(arg.debug_error_string)
                e["debug_error_string"] = parsed
            except json.decoder.JSONDecodeError:
                e["debug_error_string_raw"] = arg.debug_error_string

    md: List[Dict[str, Any]] = []
    for tmd in err.trailing_metadata():
        if not (
            hasattr(tmd, "key")
            and hasattr(tmd, "value")
            and tmd.key.startswith("grpc-status-details")
        ):
            continue

        status = goog_status.Status()
        status.MergeFromString(tmd.value)
        md.append(
            {
                "code": str(status.code),
                "message": status.message,
                "details": [
                    {
                        "type": d.type_url,
                        "value": remove_control_chars(
                            d.value.decode("utf-8", errors="backslashreplace")
                        ),
                    }
                    for d in status.details
                ],
            }
        )

    e["metadata"] = md

    return {"gRPCerror": e}
